@@ -7,9 +7,7 @@ from ormar.models import FakePydantic  # noqa I100
 
 
 class Model(FakePydantic):
-    __abstract__ = True
-
-    objects = ormar.queryset.QuerySet()
+    __abstract__ = False
 
     @classmethod
     def from_row(
@@ -22,24 +20,24 @@ class Model(FakePydantic):
         item = {}
         select_related = select_related or []
 
-        table_prefix = cls._orm_relationship_manager.resolve_relation_join(
-            previous_table, cls.__table__.name
+        table_prefix = cls.Meta._orm_relationship_manager.resolve_relation_join(
+            previous_table, cls.Meta.table.name
         )
-        previous_table = cls.__table__.name
+        previous_table = cls.Meta.table.name
         for related in select_related:
             if "__" in related:
                 first_part, remainder = related.split("__", 1)
-                model_cls = cls.__model_fields__[first_part].to
+                model_cls = cls.Meta.model_fields[first_part].to
                 child = model_cls.from_row(
                     row, select_related=[remainder], previous_table=previous_table
                 )
                 item[first_part] = child
             else:
-                model_cls = cls.__model_fields__[related].to
+                model_cls = cls.Meta.model_fields[related].to
                 child = model_cls.from_row(row, previous_table=previous_table)
                 item[related] = child
 
-        for column in cls.__table__.columns:
+        for column in cls.Meta.table.columns:
             if column.name not in item:
                 item[column.name] = row[
                     f'{table_prefix + "_" if table_prefix else ""}{column.name}'
@@ -47,22 +45,14 @@ class Model(FakePydantic):
 
         return cls(**item)
 
-    @property
-    def pk(self) -> str:
-        return getattr(self.values, self.__pkname__)
-
-    @pk.setter
-    def pk(self, value: Any) -> None:
-        setattr(self.values, self.__pkname__, value)
-
     async def save(self) -> "Model":
         self_fields = self._extract_model_db_fields()
-        if self.__model_fields__.get(self.__pkname__).autoincrement:
-            self_fields.pop(self.__pkname__, None)
-        expr = self.__table__.insert()
+        if self.Meta.model_fields.get(self.Meta.pkname).autoincrement:
+            self_fields.pop(self.Meta.pkname, None)
+        expr = self.Meta.table.insert()
         expr = expr.values(**self_fields)
-        item_id = await self.__database__.execute(expr)
-        self.pk = item_id
+        item_id = await self.Meta.database.execute(expr)
+        setattr(self, self.Meta.pkname, item_id)
         return self
 
     async def update(self, **kwargs: Any) -> int:
@@ -71,23 +61,23 @@ class Model(FakePydantic):
             self.from_dict(new_values)
 
         self_fields = self._extract_model_db_fields()
-        self_fields.pop(self.__pkname__)
+        self_fields.pop(self.Meta.pkname)
         expr = (
-            self.__table__.update()
+            self.Meta.table.update()
             .values(**self_fields)
-            .where(self.pk_column == getattr(self, self.__pkname__))
+            .where(self.pk_column == getattr(self, self.Meta.pkname))
         )
-        result = await self.__database__.execute(expr)
+        result = await self.Meta.database.execute(expr)
         return result
 
     async def delete(self) -> int:
-        expr = self.__table__.delete()
-        expr = expr.where(self.pk_column == (getattr(self, self.__pkname__)))
-        result = await self.__database__.execute(expr)
+        expr = self.Meta.table.delete()
+        expr = expr.where(self.pk_column == (getattr(self, self.Meta.pkname)))
+        result = await self.Meta.database.execute(expr)
         return result
 
     async def load(self) -> "Model":
-        expr = self.__table__.select().where(self.pk_column == self.pk)
-        row = await self.__database__.fetch_one(expr)
+        expr = self.Meta.table.select().where(self.pk_column == self.pk)
+        row = await self.Meta.database.fetch_one(expr)
         self.from_dict(dict(row))
         return self
